import { Observable, Subscription } from 'rxjs';
/**
 * An object that is backed by a comlink Proxy and exposes its Subscription so consumers can release it.
 */
export interface ProxySubscribed {
    readonly proxySubscription: Subscription;
}
/**
 * Releases the underlying MessagePort of a remote Observable when it completes or is unsubscribed from.
 *
 * Important: This will prevent resubscribing to the Observable. Only use this operator in a scope where it is known
 * that no resubscriptions can happen after completion, e.g. in a `switchMap()` callback.
 *
 * Must be used as the first parameter to `pipe()`, because the source must be a `RemoteObservable`.
 */
export declare const finallyReleaseProxy: <T>() => (source: Observable<T> & Partial<ProxySubscribed>) => Observable<T>;
//# sourceMappingURL=common2.d.ts.map