import { Subscription, switchMap, Observable } from 'rxjs';
import { createExtensionHostClientConnection } from './connection.js';
import { logger } from '@cdm-logger/client';

/**
 * Creates a client to communicate with an extension host.
 *
 * @param services
 * @param extensionHostConnection An observable that emits the connection the extension host each time a new
 * connection is established.
 */
function createExtensionHostClient(services, extensionHostConnection) {
  const subscriptions = new Subscription();
  logger.debug('createExtensionHostClient called');
  const client = extensionHostConnection.pipe(switchMap(connection => {
    const clientCon = createExtensionHostClientConnection(connection, services);
    return new Observable(sub => {
      sub.next(clientCon);
      return () => clientCon.unsubscribe();
    });
  }));
  subscriptions.add(client.subscribe());
  return {
    unsubscribe: () => subscriptions.unsubscribe()
  };
}

export { createExtensionHostClient };
//# sourceMappingURL=extension-client.js.map
